/* Demonstration of Rtc_Pcf8563 Alarms. 
 *
 * The Pcf8563 has an interrupt output, Pin3.
 * Pull Pin3 HIGH with a resistor, I used a 10kohm to 5v.
 * I used a RBBB with Arduino IDE, the pins are mapped a 
 * bit differently.  Change for your hw.
 * SCK - A5, SDA - A4, INT - D3/INT1
 *
 * After loading and starting the sketch, use the serial monitor
 * to see the clock output.
 */
#include <Wire.h>
#include <Rtc_Pcf8563.h>
#define INT 3
#define BEEP 4
#define LED 5
/* get a real time clock object */
Rtc_Pcf8563 rtc;
/* a flag for the interrupt */
volatile int alarm_flag=0;

/* the interrupt service routine */
void task()
{
  digitalWrite(LED,LOW),digitalWrite(BEEP,LOW);//open beep and led
  alarm_flag = 1;
}

void setup()
{
  pinMode(INT, INPUT);           // set pin to input
  digitalWrite(INT, HIGH);       // turn on pullup resistors
  pinMode(BEEP,OUTPUT);          // set pin to input
  digitalWrite(BEEP,HIGH);       // turn on pullup resistors
  pinMode(LED,OUTPUT);          // set pin to input
  digitalWrite(LED,HIGH);      // turn on pullup resistors
  Serial.begin(9600);
  
  /* setup int on pin 3 of arduino */
  attachInterrupt(1, task, FALLING);
  /* clear out all the registers */
  rtc.initClock();
  /* set a time to start with.
   * day, weekday, month, century, year */
  rtc.setDate(1, 5, 9, 0, 17);
  /* hr, min, sec */
  rtc.setTime(10, 56, 55);
  /* set an alarm for 20 secs later...
   * alarm pin goes low when match occurs
   * this triggers the interrupt routine
   * min, hr, day, weekday 
   * 99 = no alarm value to be set
   */
  rtc.setAlarm(57, 99, 99, 99);
}

void loop()
{
  /* each sec update the display */
  Serial.print(rtc.formatTime());
  Serial.print("  ");
  Serial.print(rtc.formatDate());
//  Serial.print("  0x");
//  Serial.print(rtc.getStatus2(), HEX);
  Serial.print("\r\n");
  delay(1000);
  if (alarm_flag==1){
    delay(2000);
    clr_alarm();
  }
}

void clr_alarm()
{
  detachInterrupt(1);
  digitalWrite(LED,HIGH),digitalWrite(BEEP,HIGH);//close beep and led
  rtc.clearAlarm();
  delay(1000);
  alarm_flag=0;
  attachInterrupt(1, task, FALLING);
}

